pyxmpp2.sasl.core.Success

Package pyxmpp2 :: Package sasl :: Module core :: Class Success |
[hide private]

# Class Success

The success SASL message (sent by the server on authentication success).

Instance Methods | [hide private]
__init__(self, username, realm=None, authzid=None, data=None, encode=True) Initialize the Success object. |
__repr__(self) repr(x) |
Inherited from `Reply`: `encode` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Instance Variables | [hide private]
Inherited from `Reply`: `data` Inherited from `Reply` (private): `_encode`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, username, realm=None, authzid=None, data=None, encode=True) (Constructor) |
Initialize the Success object. Parameters: `username` (`unicode`) - authenticated username (authentication id). `realm` (`unicode`) - authentication realm used. `authzid` (`unicode`) - authorization id. `data` (`str`) - the success data to be sent to the client. `encode` (`bool`) - whether to base64 encode the data or not Overrides: object.__init__

### __repr__(self) (Representation operator) |
repr(x) Overrides: object.__repr__ (inherited documentation)